"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-unused-vars */
const command_1 = require("@oclif/command");
const { AutoComplete, Select, Form, Confirm, Editable } = require('clipprs-enquirer');
const Table = require('cli-table3');
const path = require('path');
const defaults = require('./../../config/settings.json');
/// DATABASE ///
// initialize db
const low = require('lowdb');
const FileSync = require('lowdb/adapters/FileSync');
const adapter = new FileSync(path.join(defaults.db.path, defaults.db.filename));
const db = low(adapter);
// setup defaults //
db.defaults(defaults.db.defaults)
    .write();
/// \DATABASE ///
function editPerson(entry) {
    const editPersonPrompt = new Editable({
        name: 'edit-entry',
        message: 'Edit a Clip - ',
        choices: () => {
            const prompt_choices = [];
            // eslint-disable-next-line guard-for-in
            for (const key in entry) {
                const field = {
                    name: key,
                    message: key,
                    initial: entry[key],
                    editable: true,
                    required: defaults.requiredFields.includes(key),
                };
                prompt_choices.push(field);
            }
            return prompt_choices;
        },
    });
    editPersonPrompt.run()
        .then((editedEntry) => {
        db.get('people')
            .remove(entry)
            .write();
        db.get('people')
            .push(editedEntry)
            .write();
    });
}
const viewEditDeleteClose = new Select({
    name: '',
    message: '',
    choices: ['View', 'Edit', 'Delete', 'Close'],
});
const confirmDeletePrompt = new Confirm({
    name: 'confirm-delete',
    message: 'Delete?',
});
// dynamically generate prompt from template
const searchPrompt = new AutoComplete({
    name: 'search-entry',
    message: 'Search and edit your Clips - ',
    choices: () => {
        const prompt_choices = [];
        const dbData = db.get('people').value();
        for (const entry of dbData) {
            prompt_choices.push(`${entry['First Name']} ${entry['Last Name']}`);
        }
        // prompt_choices.push(BLANK_INPUT_TEMPLATE)
        return prompt_choices;
    },
});
// import {DB_PATH} from '../definitions'
// const fs = require('fs')
class New extends command_1.Command {
    // first we search through all our entries
    // then, we allow the user to edit or delete the entry
    async run() {
        searchPrompt.run()
            .then((answer) => {
            const dbData = db.get('people').value();
            const [firstName, lastName] = answer.split(' ');
            const entry = db.get('people')
                .find({ 'First Name': firstName, 'Last Name': lastName })
                .value();
            viewEditDeleteClose.run()
                .then((answer) => {
                // VIEW
                if (answer === 'View') {
                    // widen colWidth as we are only displaying 2 colums
                    const columnWidth = defaults.view.columnWidth;
                    const table = new Table({ wordWrap: true, colWidths: [columnWidth * 1.5, columnWidth * 1.5] });
                    const keys = Object.keys(entry);
                    for (const key of keys) {
                        // use es6 computed name properties
                        table.push({
                            [key]: entry[key],
                        });
                    }
                    this.log(table.toString());
                    // EDIT
                }
                else if (answer === 'Edit') {
                    editPerson(entry);
                    this.log('Edits successfully saved.');
                    // DELETE
                }
                else if (answer === 'Delete') {
                    confirmDeletePrompt.run()
                        .then((answer) => {
                        if (answer === true) {
                            db.get('people')
                                .remove({ 'First Name': firstName, 'Last Name': lastName })
                                .write();
                            // sanity check to ensure n > 0 always
                            db.update('count', (n) => (n > 0) ? (n - 1) : (n))
                                .write();
                        }
                        else {
                            this.log('Cancelling deletion.');
                        }
                    });
                    // CLOSE
                }
                else if (answer === 'Close') {
                    // CLOSE
                    // instead of closing, we could return to the search field
                    // eslint-disable-next-line no-useless-return
                    return;
                }
            });
        })
            .catch(console.error);
    }
}
exports.default = New;
New.description = 'Search through your Clips';
New.flags = {
    help: command_1.flags.help({ char: 'h' }),
};
